capture restore
capture set trace off
capture clear
capture log close
set more 1
clear matrix
clear mata
set matsize 5000
set seed /*078*/06709096

global folder "C:\Users\name\Desktop\" 
cd "$folder"
**********************OUTPUT**********************************************************************
**********************TABLE**********************
use "$folder\ScanTax_data.dta", clear

gen oecd_incometax = oecd_t1000+oecd_t2000+oecd_t3000 
rename oecd_t4000 oecd_propertytax
rename oecd_t5000 oecd_consumptiontax
rename oecd_t6000 oecd_othertax


sort Country year
keep if Code == "SWE" | Code == "NOR" | Code == "DNK" | Code == "USA" | Code == "GBR" | Code == "DEU"
keep Country Code year ief_taxpergdp2012 oecd_incometax oecd_consumptiontax oecd_propertytax pss_topmit oecd_entrytax_emp20to59

collapse (lastnm) ief_taxpergdp2012 oecd_incometax oecd_consumptiontax oecd_propertytax pss_topmitr oecd_entrytax_emp20to59, by(Country Code)

label var ief_taxpergdp2012 "Tax / GDP"
label var oecd_incometax "Income taxes as a share of tax revenue"
label var oecd_propertytax "Property taxes as a share of tax revenue" 
label var oecd_consumptiontax "Consumption taxes as a share of tax revenue"  
label var pss_topmit "Top marginal income tax rate"
label var oecd_entrytax_emp20to59 "Participation tax rate"

gen order = .
replace order = 1 if Code == "DNK"
replace order = 2 if Code == "NOR" 
replace order = 3 if Code == "SWE" 
replace order = 4 if Code == "DEU" 
replace order = 5 if Code == "GBR" 
replace order = 6 if Code == "USA"  

sort order
drop order Code

order Country ief_taxpergdp2012 oecd_incometax oecd_propertytax oecd_consumptiontax pss_topmitr oecd_entrytax_emp20to59
export excel using "$estout\Table1.xls", firstrow(varlabels) replace sheet("Table 1") 

**********************PLOTS**********************
use "$folder\ScanTax_data.dta", clear

replace clock = 3
replace clock = 9 if Code == "DNK" | Code == "NOR" | Code == "SWE"

save tmp1, replace
graph set window fontface "Times New Roman"

*doing only OECD countries in the first part
keep if OECD == 1
save tmp, replace
use tmp, clear
*************************************************
*FIGURE 4a: LABOR FORCE PARTICIPATION vs OECD ENTRY AVERAGE TAX (A LA MENDOZA; OECD DEFINITIONS OF CONSUMPTION TAX)

local year "20to59" 
foreach y of local year {
local var "emp`y'"
foreach v of local var {

drop if oecd_entrytax_`v' == . | oecd_`v' == .
sort Country Code year

collapse (lastnm) oecd_`v' oecd_entrytax_`v' clock year inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc, by(Country Code)
replace clock = 11 if Code == "NOR"
replace clock = 8 if Code == "SWE"
replace clock = 12 if Code == "JPN"
replace clock = 4 if Code == "GBR"

*DISPLAYING "1 - PARTICIPATION TAX RATE" RATHER THAN PARTICIPATION TAX RATE IN FIGURE 4
capture label var oecd_entrytax_`v' "1 - participation tax rate"
replace oecd_entrytax_`v' = 1 - oecd_entrytax_`v'

save "$folder\puretmp.dta", replace  
 
graph twoway (scatter oecd_`v' oecd_entrytax_`v' if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter oecd_`v' oecd_entrytax_`v' if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter oecd_`v' oecd_entrytax_`v' if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit oecd_`v' oecd_entrytax_`v', legend(off) clcolor(black) ylabel(.5(.1).9) xlabel(.1(.1).8) ysc(r(.5 .9)) xsc(r(.0 .8)) ytitle("Employment rate") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure4a.emf", as(emf) replace
graph export "$folder\Figure4a.png", width(3900) as (png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) replace sheet("Figure 4a")

reg oecd_`v' oecd_entrytax_`v', r
gen c1 = _b[_cons]
local c1 _b[_cons]
gen b1 = _b[oecd_entrytax_emp20to59]
local b1 _b[oecd_entrytax_emp20to59]
rename oecd_emp y1
rename oecd_entrytax_emp20to59 x1
keep Code c1 b1 x1 y1
save tmp2, replace 

use tmp, clear
***************************
*Figure 5a: LABOR FORCE PARTICIPATION vs LABOR SUBSIDY SHARE
keep Country Code year cyear laborsubsidy_share   oecd_`v' pwt_labshr_gdp oecd_childcarepresch oecd_elderlycare SPEED_transpexp_shrgdp imf_govexp_transport clock

drop if laborsubsidy_share == . |  oecd_`v' == .
replace laborsubsidy_share = laborsubsidy_share / pwt_labshr_gdp
sort Country Code year
collapse (lastnm)  oecd_`v' laborsubsidy_share oecd_childcarepresch oecd_elderlycare SPEED_transpexp_shrgdp imf_govexp_transport  clock year, by(Country Code)

replace clock = 9
replace clock = 3 if Code == "DNK" | Code == "SWE"
replace clock = 12 if Code == "DNK"
replace clock = 5 if Code == "MEX"
replace clock = 9 if Code == "ITA"
replace clock = 1 if Code == "NOR" 

capture label var laborsubsidy_share "Employment subsidies (share of labor income)"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter  oecd_`v' laborsubsidy_share if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter  oecd_`v' laborsubsidy_share if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter  oecd_`v' laborsubsidy_share if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit  oecd_`v' laborsubsidy_share, legend(off) clcolor(black)  ylabel(.2(.1).9) xlabel(.0(.01).06) ysc(r(.2 .9)) xsc(r(-0.007 .07)) ytitle("Employment rate") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure5a.emf", as(emf) replace
graph export "$folder\Figure5a.png", width(3900) as (png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 5a")
use tmp, clear
***************************
***************************
*Figure 4b : FEMALE EMPLOYMENT VS PARTICIPATION TAXES / SUBSIDIES
replace laborsubsidy_share = laborsubsidy_share / pwt_labshr_gdp
drop if oecd_elderlycare == . | wb_laborforce_rate == .
replace oecd_elderlycare = oecd_elderlycare / pwt_labshr_gdp
replace oecd_childcarepresch = oecd_childcarepresch / pwt_labshr_gdp

capture label var oecd_f_`v' "Female employment rate"
local label : variable label oecd_f_`v'

save tmp3, replace
drop if oecd_entrytax_`v' == . | oecd_f_`v' == .
sort Country Code year
collapse (lastnm) oecd_f_`v' oecd_`v' oecd_entrytax_`v' clock year inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc, by(Country Code)

replace clock = 11 if Code == "NOR"
replace clock = 4 if Code == "GBR"
replace clock = 12 if Code == "DEU"

*DISPLAYING "1 - PARTICIPATION TAX RATE" RATHER THAN PARTICIPATION TAX RATE IN FIGURE 4
capture label var oecd_entrytax_`v' "1 - participation tax rate"
replace oecd_entrytax_`v' = 1 - oecd_entrytax_`v'

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter oecd_f_`v' oecd_entrytax_`v' if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter oecd_f_`v' oecd_entrytax_`v' if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter oecd_f_`v' oecd_entrytax_`v' if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit oecd_f_`v' oecd_entrytax_`v', legend(off) clcolor(black)  ylabel(.5(.1).9) xlabel(.1(.1).8) ysc(r(.5 .9)) xsc(r(.0 .8)) ytitle(`label') graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure4b.emf", as(emf) replace
graph export "$folder\Figure4b.png", width(3900) as (png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 4b")

reg oecd_f_`v' oecd_entrytax_`v', r
gen c2 = _b[_cons]
local c2 _b[_cons]
gen b2 = _b[oecd_entrytax_emp20to59]
local b2 _b[oecd_entrytax_emp20to59]

rename oecd_f_emp y2
rename oecd_entrytax_emp20to59 x2
keep Code c2 b2 x2 y2

merge 1:1 Code using tmp2
tab _merge
drop _merge
save tmp2, replace 

use tmp3, clear

*********************************************************
*FIGURE 5b: employment subsidies vs female employment
save tmp3, replace
drop if laborsubsidy_share == . | oecd_f_`v' == .
sort Country Code year
collapse (lastnm) oecd_f_`v' laborsubsidy_share clock year, by(Country Code)

replace clock = 9
replace clock = 3 if Code == "NOR" 
replace clock = 12 if Code == "DNK"
replace clock = 4 if Code == "SWE"
replace clock = 8 if Code == "MEX"
replace clock = 10 if Code == "DEU"
replace clock = 11 if Code == "GBR"

capture label var laborsubsidy_share "Employment subsidies (share of labor income)"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter oecd_f_`v' laborsubsidy_share if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter oecd_f_`v' laborsubsidy_share if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter oecd_f_`v' laborsubsidy_share if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit oecd_f_`v' laborsubsidy_share, legend(off) clcolor(black)   ylabel(.2(.1).9) xlabel(.0(.01).06) ysc(r(.2 .9)) xsc(r(-0.007 .07)) ytitle(`label') graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure5b.emf", as(emf) replace
graph export "$folder\Figure5b.png", width(3900) as (png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 5b")
use tmp3, clear
}
}
*************************************************
*FIGURE A2a (tax rate calculated without out-of work transfers, for 1995): FOR TOTAL POPULATION
use tmp, clear
keep if year == 1995
drop if oecd_entrytax_emp20to59_notransf == . | oecd_entrytax_emp20to59 == . | oecd_emp20to59 == .
sort Country Code year

*DISPLAYING "1 - PARTICIPATION TAX RATE" RATHER THAN PARTICIPATION TAX RATE IN FIGURE 4
replace oecd_entrytax_emp20to59 = 1 - oecd_entrytax_emp20to59
replace oecd_entrytax_emp20to59_notransf = 1 - oecd_entrytax_emp20to59_notransf

*adding the regression results from the current paper (Figure 4a, to plot the dashed line
merge 1:1 Code using tmp2
tab _merge
drop _merge
save tmp2, replace 

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (lfit y1 x1										  , xlabel(.1(.1).8) ylabel(.5(.05).85) xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) xtitle("1 - participation tax rate") lpattern(l) lcolor(black))  ///
	         (lfit oecd_emp20to59 oecd_entrytax_emp20to59		  , xlabel(.1(.1).8) ylabel(.5(.05).85) xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) clcolor(black) ytitle("Employment rate") lpattern(longdash) graphregion(color(white)) bgcolor(white)) ///
	         (lfit oecd_emp20to59 oecd_entrytax_emp20to59_notransf, xlabel(.1(.1).8) ylabel(.5(.05).85) xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) clcolor(black) ytitle("Employment rate") lpattern(shortdash) graphregion(color(white)) bgcolor(white) legend(cols(1) ring(0) pos(8) order(1 "Latest year, with transfers (baseline)" 2 "1995, with transfers" 3 "1995, without transfers"))) 
graph export "$folder\FigureA2a.emf", as(emf) replace
graph export "$folder\FigureA2a.png", width(3900) as(png) replace

keep Country Code year oecd_emp20to59 oecd_entrytax_emp20to59 oecd_entrytax_emp20to59_notransf inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Appendix Figure 2a")

*************************************************
*FIGURE A2b (tax rate calculated without out-of work transfers, for 1995): FOR FEMALE POPULATION
use tmp, clear
keep if year == 1995
		
drop if oecd_entrytax_emp20to59_notransf == . | oecd_f_emp20to59 == .
sort Country Code year

*DISPLAYING "1 - PARTICIPATION TAX RATE" RATHER THAN PARTICIPATION TAX RATE IN FIGURE 4
replace oecd_entrytax_emp20to59 = 1 - oecd_entrytax_emp20to59
replace oecd_entrytax_emp20to59_notransf = 1 - oecd_entrytax_emp20to59_notransf

*adding the regression results from our paper, to plot the dashed line
merge 1:1 Code using tmp2
tab _merge
drop _merge
save tmp2, replace 

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (lfit y2 x2   											, xlabel(.1(.1).8) ylabel(.5(.05).85)  xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) xtitle("1 - participation tax rate") lpattern(l) lcolor(black))  ///
	         (lfit oecd_f_emp20to59 oecd_entrytax_emp20to59			, xlabel(.1(.1).8) ylabel(.5(.05).85)  xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) clcolor(black) ytitle("Female employment rate") lpattern(longdash) graphregion(color(white)) bgcolor(white)) /// 
	         (lfit oecd_f_emp20to59 oecd_entrytax_emp20to59_notransf, xlabel(.1(.1).8) ylabel(.5(.05).85)  xsc(r(.05 .85)) ysc(r(.5 .85)) range (.1 .8) clcolor(black) ytitle("Female employment rate") lpattern(shortdash) graphregion(color(white)) bgcolor(white) legend(cols(1) ring(0) pos(8) order(1 "Latest year, with transfers (baseline)"  2 "1995, with transfers" 3 "1995, without transfers")))

graph export "$folder\FigureA2b.emf", as(emf) replace
graph export "$folder\FigureA2b.png", width(3900) as(png) replace

keep Country Code year  oecd_f_emp20to59 oecd_entrytax_emp20to59 oecd_entrytax_emp20to59_notransf oecd_emp20to59 inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Appendix Figure 2b")
*************************************************
*FIGURE A3: HOURS WORKED VS TOP MARGINAL TAX RATE
use tmp, clear

drop if pss_topmitr == . | oecd_hoursworked == .
sort Country Code year
collapse (lastnm) oecd_hoursworked pss_topmitr clock year, by(Country Code)

replace clock = 12 if Code == "AUS"


*DISPLAYING "1 - PARTICIPATION TAX RATE" RATHER THAN PARTICIPATION TAX RATE IN FIGURE 4
capture label var pss_topmitr "1- top marginal tax rate"
replace pss_topmitr = 1 - pss_topmitr
replace clock = 4 if Country == "Netherlands"
replace clock = 2 if Code == "DEU"
replace clock = 6 if Code == "GBR"
replace clock = 3 if Code == "JPN"
replace clock = 12 if Code == "ITA"
replace clock = 12 if Code == "USA"
replace clock = 3 if Country == "New Zealand"
replace clock = 11 if Code == "FIN"
replace clock = 9 if Code == "AUS"
replace clock = 8 if Code == "DNK"


preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter oecd_hoursworked pss_topmitr, mlabvpos(clock) ylabel(1000(200)2000) ysc(r(1000 2000)) xsc(r(.2 .63)) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit oecd_hoursworked pss_topmitr, legend(off) clcolor(black) ytitle("Average annual hours worked") graphregion(color(white)) bgcolor(white))
graph export "$folder\FigureA3.emf", as(emf) replace
graph export "$folder\FigureA3.png",  width(3900) as(png) replace

export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Appendix Figure 3")
***************************
*NON-OECD COUNTRIES + OECD
use tmp1, clear

*keep if year >= 2000
keep if OECD == 1 | wb_natresorents_pct_gdp < 0.20
drop if gdppc_ppp < 5000 | gdppc_ppp == .

save tmp, replace
*************************************************
*FIGURE 2a: TAX vs THIRD PARTY REPORTING SHARES (using self-emp / emp+self_emp (USING WORLD BANK DATA)
keep Country Code year cyear ief_taxpergdp2012 wb_employees_empselfemp wb_employers_empselfemp clock

gen wb_selfemp_empselfemp = 1-wb_employees_empselfemp

drop if wb_selfemp_empselfemp == . | ief_taxpergdp2012 == .

*FIGURE 2a: using LAST available data for a given country, regardless of the year (USING WORLD BANK DATA)
sort Country Code year
collapse (lastnm) ief_taxpergdp2012 wb_selfemp_empselfemp clock year, by(Country Code)

replace clock = 4 if Code == "GBR"

capture label var wb_selfemp_empselfemp "Fraction self-employed"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter ief_taxpergdp2012 wb_selfemp_empselfemp if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter ief_taxpergdp2012 wb_selfemp_empselfemp if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 wb_selfemp_empselfemp if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 wb_selfemp_empselfemp, xsc(r(-0.05 .8)) legend(off) clcolor(black) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure2a.emf", as(emf) replace
graph export "$folder\Figure2a.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 2a")

use tmp, clear
*************************************************
*FIGURE 2b: TAX vs THIRD PARTY REPORTING SHARES (using evasive + self-emp / emp+self_emp) [WB self-employment]
keep Country Code year cyear ief_taxpergdp2012 wb_employees_empselfemp ilo_evasivesectemp wb_emplaborforce_rate ilo_selfemp wb_employers_empselfemp clock

gen wb_selfemp_empselfemp = 1-wb_employees_empselfemp
gen selfempevasive = wb_selfemp_empselfemp + ilo_evasivesectemp

drop if selfempevasive == . | ief_taxpergdp2012 == .

*Plot 1d: using LAST available data for a given country, regardless of the year
sort Country Code year
collapse (lastnm) ief_taxpergdp2012 selfempevasive clock year, by(Country Code)

replace clock = 4 if Code == "GBR"
capture label var selfempevasive "Fraction of self-employed and employees in evasive jobs"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter ief_taxpergdp2012 selfempevasive if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter ief_taxpergdp2012 selfempevasive if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 selfempevasive if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 selfempevasive, legend(off) clcolor(black) ysc(r(.08 .5)) xsc(r(.2 .85)) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure2b.emf", as(emf) replace
graph export "$folder\Figure2b.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 2b")

use tmp, clear
*************************************************
*FIGURE 6a: TAX vs trust people
keep Country Code year cyear ief_taxpergdp2012 wvs_trustpeople clock
drop if wvs_trustpeople == . | ief_taxpergdp2012 == .

*making sure the samples for plots 3a and 3b match (dropping PERU 2008, and instead using PERU 2001; dropping ISRAEL 2001): 
drop if cyear == "PER2008" | cyear == "ISR2001"

*Plot 6a: using LAST available data for a given country, regardless of the year
sort Country Code year
collapse (lastnm) ief_taxpergdp2012 wvs_trustpeople clock year, by(Country Code)

replace clock = 9
replace clock = 3 if Code == "DNK" | Code == "NOR" | Code == "SWE"
replace clock = 6 if Code == "GBR"
replace clock = 4 if Code == "ITA"

capture label var wvs_trustpeople "'Most people can be trusted'" 

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter ief_taxpergdp2012 wvs_trustpeople if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter ief_taxpergdp2012 wvs_trustpeople if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 wvs_trustpeople if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 wvs_trustpeople, legend(off) clcolor(black) ysc(r(.08 .5)) xsc(r(.1 .9)) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure6a.emf", as(emf) replace
graph export "$folder\Figure6a.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 6a")

use tmp, clear
*************************************************
*FIGURE 6b: PEOPLE IN NEED BECAUSE OF THEIR LAZINESS / LACK OF WILL-POWER
*for 6b, do not drop the pre-2000 observations
use tmp1, clear
keep if OECD == 1 | wb_natresorents_pct_gdp < 0.20
drop if gdppc_ppp < 5000 | gdppc_ppp == .
*********************
keep Country Code year cyear ief_taxpergdp2012 wvs_inneed_lazy clock
drop if wvs_inneed_lazy == . | ief_taxpergdp2012 == .

*Plot 6b: using LAST available data for a given country, regardless of the year
sort Country Code year
collapse (lastnm) ief_taxpergdp2012 wvs_inneed_lazy clock year, by(Country Code)

replace clock = 4 if Code == "GBR"
replace clock = 2 if Code == "USA"
replace clock = 2 if Code == "ITA"

capture label var wvs_inneed_lazy "'People in need because of laziness, lack of willpower'"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
qui reg ief_taxpergdp2012 wvs_inneed_lazy
 reg ief_taxpergdp2012 wvs_inneed_lazy

graph twoway (scatter ief_taxpergdp2012 wvs_inneed_lazy if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter ief_taxpergdp2012 wvs_inneed_lazy if Code == "DNK" | Code == "NOR" | Code == "SWE" | Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 wvs_inneed_lazy if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 wvs_inneed_lazy, legend(off) clcolor(black)  ysc(r(.05 .5)) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure6b.emf", as(emf) replace
graph export "$folder\Figure6b.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 6b")
*************************************************
use tmp, clear
*FIGURE 6c: TAX vs SOCIAL CAPITAL PROXY INDEX (VIA PCA)
keep Country Code year cyear ief_taxpergdp2012 sk_proxy_wo_relig polity2 clock
*DEMOCRACIES ONLY
keep if polity2 > 0
drop if sk_proxy_wo_relig == . | ief_taxpergdp2012 == .

*Plot 6c: using LAST available data for a given country, regardless of the year
sort Country Code year
collapse (lastnm) ief_taxpergdp2012 sk_proxy_wo_relig clock year, by(Country Code)

replace clock = 9
replace clock = 3 if Code == "DNK" | Code == "SWE"
replace clock = 2 if Code == "NOR"
replace clock = 6 if Code == "ITA"

capture label var sk_proxy_wo_relig "Social capital index"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter ief_taxpergdp2012 sk_proxy_wo_relig if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10) mlabcolor(gs12)) ///
			 (scatter ief_taxpergdp2012 sk_proxy_wo_relig if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 sk_proxy_wo_relig if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 sk_proxy_wo_relig, legend(off) clcolor(black) ysc(r(.08 .5)) xsc(r(-2 3.5)) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure6c.emf", as(emf) replace
graph export "$folder\Figure6c.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 6c")
*************************************************
use tmp, clear
******************************************************************************************************************
*FIGURE 6d: TAX vs Percent people donating money
keep Country Code year cyear ief_taxpergdp2012  wgi_donatemoney2012 clock
keep if year >= 2008
drop if  wgi_donatemoney2012 == . | ief_taxpergdp2012 == .

sort Country Code year
collapse (lastnm) ief_taxpergdp2012  wgi_donatemoney2012 clock, by(Country Code)
gen year = 2012

replace clock = 9
replace clock = 3 if Code == "DNK" | Code == "NOR" | Code == "SWE"

capture label var wgi_donatemoney2012 "Fraction of people donating money to charity"

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter ief_taxpergdp2012 wgi_donatemoney2012 if Code != "DNK" & Code != "NOR" & Code != "SWE" & Code != "USA" & Code != "GBR" & Code != "DEU" & Code != "ITA" & Code != "JPN" & Code != "IND" & Code != "CHN" & Code != "BRA" & Code != "MEX", mlabvpos(clock) msize(small) ml() mcolor(gs10)) ///
			 (scatter ief_taxpergdp2012 wgi_donatemoney2012 if Code == "USA" | Code == "GBR" | Code == "DEU" | Code == "ITA" | Code == "JPN" | Code == "IND" | Code == "CHN" | Code == "BRA" | Code == "MEX", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
			 (scatter ief_taxpergdp2012 wgi_donatemoney2012 if Code == "DNK" | Code == "NOR" | Code == "SWE", mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black)) ///
	         (lfit ief_taxpergdp2012 wgi_donatemoney2012, legend(off) clcolor(black) ysc(r(.08 .5)) xsc(r(0 .9)) ytitle("Tax / GDP ratio") graphregion(color(white)) bgcolor(white))
graph export "$folder\Figure6d.emf", as(emf) replace
graph export "$folder\Figure6d.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 6d")

use tmp, clear
***************************
*NON-OECD COUNTRIES + OECD
use tmp1, clear

keep if year >= 1998
keep if OECD == 1 | wb_natresorents_pct_gdp < 0.20
drop if gdppc_ppp < 5000 | gdppc_ppp == .

save tmp, replace
***************************
*FIGURE A1a: RANGE .3-.9
use tmp, clear 
*USE THE AGE GROUP BETWEEN 20 and 59
local year "20to59" 
foreach y of local year {
foreach var of varlist oecd_entrytax_emp`y' {
use tmp, clear

replace Country = "Denmark" if Code == "DNK"
replace Country = "Norway" if Code == "NOR"
replace Country = "Sweden" if Code == "SWE"

keep Country Code year cyear EJ07_partictax_earnweight `var' oecd_emp20to59 clock inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc
drop if EJ07_partictax_earnweight == . | `var' == .

sort Country Code year
collapse (lastnm) EJ07_partictax_earnweight `var' clock year oecd_emp20to59 inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc, by(Country Code)

replace clock = 3
replace clock = 3 if Code == "DNK" | Code == "NOR" | Code == "SWE"
replace clock = 2 if Code == "ESP" 
replace clock = 4 if Country == "Greece"
replace clock = 2 if Code == "LUX" 
replace clock = 4 if Country == "Italy"
replace clock = 6 if Code == "GRC"
replace clock = 2 if Country == "France"
replace clock = 4 if Code == "DEU"

corr `var' EJ07_partictax_earnweight
local rho: display %5.4f r(rho)

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter  `var' EJ07_partictax_earnweight, mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black) xtitle("Micro-based participation tax rate (1998)") ytitle("Macro-based participation tax rate (1998)") lcolor(green) graphregion(color(white)) bgcolor(white) ylabel(.3(.1).9) xlabel(.3(.1).9) ysc(r(.3 .9)) xsc(r(.3 .9))) ///
			 (function y=x, range(0.3 .9) lpattern(dash) lcolor(black) legend(ring(0) pos(10) order(2 "45 line")))
graph export "$folder\FigureA1a.emf", as(emf) replace
graph export "$folder\FigureA1a.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Appendix Figure 1a")


use tmp, clear

***************************
use tmp, clear
*FIGURE A1b: EJ07 1st-3rd decile participation taxes (employment weighted, simulation based) vs Mendoza-style participation taxes for current paper: 1998
keep Country Code year cyear EJ07_partictax_dec1to3 `var' oecd_emp20to59 clock inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc
drop if EJ07_partictax_dec1to3 == . | `var' == .

replace Country = "Denmark" if Code == "DNK"
replace Country = "Norway" if Code == "NOR"
replace Country = "Sweden" if Code == "SWE"

sort Country Code year
collapse (lastnm) EJ07_partictax_dec1to3 `var' clock year  oecd_emp20to59 inctax_shr_labinc payroll_empees_shr_inc payroll_empers_shr_inc consmpttax_shr_consmpt_MND OoWbenefits_shr_labinc, by(Country Code)

replace clock = 3
replace clock = 3 if Code == "DNK" | Code == "NOR" | Code == "SWE"
replace clock = 2 if Code == "LUX" 
replace clock = 4 if Country == "Italy"
replace clock = 6 if Code == "GRC"
replace clock = 2 if Country == "France"

corr `var' EJ07_partictax_dec1to3
local rho: display %5.4f r(rho)

preserve
merge 1:1 Code year using "$folder\puretmp.dta"
drop _merge
save "$folder\puretmp.dta", replace 
restore 
 
graph twoway (scatter  `var' EJ07_partictax_dec1to3, mlabvpos(clock) msize(small) ml(Country) mlabsize(medsmall) mcolor(black) mlabcolor(black) xtitle("Micro-based participation tax rate, bottom-three earnings deciles (1998)") ytitle("Macro-based participation tax rate (1998)") lcolor(green) graphregion(color(white)) bgcolor(white) ylabel(.3(.1).9) xlabel(.3(.1).9) ysc(r(.3 .9)) xsc(r(.3 .9))) ///
			 (function y=x, range(0.3 .9) lpattern(dash) lcolor(black) legend(ring(0) pos(10) order(2 "45 line")))
graph export "$folder\FigureA1b.emf", as(emf) replace
graph export "$folder\FigureA1b.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Appendix Figure 1b")
}
}
***************************
*FIGURE 1 (ECONOMETRICA SELF-REPORTED / THIRD PARTY REPORTING PLOT)
import excel using "$folder\Kleven et al 2011 - Econometrica\JEP Evasion Graph.xlsx", sheet(formatted) firstrow clear
		
graph twoway (connected  tot_evasionrate fractioninc_selfrep, msymbol(diamond) mcolor(red) lcolor(red)) ///
			 (connected  thirdpartyevasion fractioninc_selfrep, msymbol(square) mcolor(black) mlabcolor(black) lpattern(longdash) lcolor(black))  ///
			 (function y=x, range(0 1) lpattern(shortdash) lcolor(black) ytitle("Evasion rate") xtitle("Fraction of income self-reported") graphregion(color(white)) bgcolor(white)  legend(ring(0) pos(10) order(1 "Total evasion rate" 2 "Third party evasion rate" 3 "45 line")))
graph export "$folder\Figure1.emf", as(emf) replace
graph export "$folder\Figure1.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 1")

***************************
*FIGURE 3 (KLEVEN et al 2013 AEJ-Policy Figure 4 on taxable income responses to the Danish 1987 tax reform)
import excel using "$folder\Kleven et al 2013 - AEJ-Policy\figs&tables_AEJPol-Final.xlsx", sheet(formatted_fig4) firstrow clear
	
graph twoway (line  taxcuts_a year, lcolor(red)  lwidth(medthick) text(92.5 1987.5 "{bf:DD Elasticity = 0.214 (0.011)}", place(e)))  ///
			 (line  taxincr_a year, lpattern(dash) lcolor(black) lwidth(medthick)  ysc(r(90 120)) ylab(90(5)120)   xsc(r(1982 1993)) xlab(1982(1)1993) xline(1986, lcolor(black) lwidth(medium)) bgcolor(white) graphregion(color(white)) ytitle("Labor income (index 1986 = 100)") xtitle("") legend(ring(1) pos(6) order(1 "Tax cuts" 2 "Tax increases"))) 
graph export "$folder\Figure3a.emf", as(emf) replace
graph export "$folder\Figure3a.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 3a")			 
	
graph twoway (line  taxcuts_c year, lcolor(red)  lwidth(medthick) text(85 1987.5 "{bf:DD Elasticity = 0.278 (0.063)}", place(e)))  ///
			 (line  taxincr_c year, lpattern(dash) lcolor(black) lwidth(medthick)  ysc(r(80 130)) ylab(80(10)130)   xsc(r(1982 1993)) xlab(1982(1)1993) xline(1986, lcolor(black) lwidth(medium)) bgcolor(white) graphregion(color(white)) ytitle("Labor income (index 1986 = 100)") xtitle("") legend(ring(1) pos(6) order(1 "Tax cuts" 2 "Tax increases"))) 
graph export "$folder\Figure3b.emf", as(emf) replace
graph export "$folder\Figure3b.png", width(3900) as(png) replace
export excel using "$folder\ScandinavianTaxes_dataset.xls", firstrow(varlabels) sheetmodify sheet("Figure 3b")			
***************************
	
cap erase "$folder\puretmp.dta"
cap erase "$folder\tmp.dta"
